#
# spec file for package krunvm
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           krunvm
Version:        0.2.3+git12dac81
Release:        2.7
Summary:        Manage lightweight VMs created from OCI images
License:        Apache-2.0
URL:            https://github.com/containers/krunvm
Source0:        krunvm-%{version}.tar.gz
Source1:        vendor.tar.zst
Source2:        cargo_config
ExclusiveArch:  x86_64 aarch64
BuildRequires:  cargo-packaging
BuildRequires:  libkrun-devel
BuildRequires:  zstd
BuildRequires:  rubygem(asciidoctor)
Requires:       buildah
Requires:       libkrun1 >= 1.4.4
Conflicts:      libkrun0

%description
Manage lightweight VMs created from OCI images

%files
%doc README.md
%{_bindir}/krunvm

%prep
%setup -qa1
mkdir .cargo
cp %{SOURCE2} .cargo/config

%build
export RUSTFLAGS="%{build_rustflags}"
%make_build

%install
export RUSTFLAGS="%{build_rustflags}"
%make_install PREFIX=%{_prefix}

%changelog
* Thu Aug 10 2023 Dominique Leuenberger <dimstar@opensuse.org>
- Use build_rustflags instead of deprecated __rustflags.
* Tue Jan  3 2023 fcrozat@suse.com
- Update to version 0.2.3+git12dac81:
  * Bump version to v0.2.3
  * macos: add support for creating x86 microVMs
* Fri Sep 30 2022 Dario Faggioli <dfaggioli@suse.com>
- Switch to the new libkrun1 library and devel package as dependencies
- Fix build on all distros by explicitly requiring zstd
* Wed Sep 28 2022 dfaggioli@suse.com
- Update to version 0.2.2+gite67d0ea:
  * Bump version to v0.2.2
  * Restrict the number of values of "-p" and "-v"
  * Bump version to v0.2.1
  * macos: fix root ownership and mode
  * Bump version to v0.2.0
  * Avoid overriding PATH
  * Use krun_set_env to set env vars
  * macos: Add missing BuildahCommand
  * Export container config on microVM creation
  * Remove command and workdir defaults
  * Bump version to 0.1.6
  * Cargo: add description and repository
  * ci: Add a step to install asciidoctor
  * Fix some clippy warnings
  * Replace "lightweight VM" with "microVM"
  * Add manual pages
  * README.md: Replace lightweight VMs with microVMs
  * README.md: remove "Limitations" section
  * Rename Security.md to SECURITY.md
* Fri May  6 2022 Frederic Crozat <fcrozat@suse.com>
- Update to version 0.1.5+giteedd405:
  * Bump version to 0.1.5
  * Refactor buildah args generation
  * Add Security and C-O-C docs
  * chore: add Cargo.lock file
  * Create directory leading up to resolv.conf
  * Bump version to 0.1.4
  * main: Fix APFS volume help message
  * changevm: Fix "cpus" and "mem" arguments
  * ci: Add code quality checks for PRs
  * Fix some cargo and clippy warnings
- Switch vendor tarball to zstd
* Tue Nov  2 2021 william.brown@suse.com
- Update to version 0.1.4+git5add8c5:
  * chore: add Cargo.lock file
  * Create directory leading up to resolv.conf
  * Bump version to 0.1.4
  * main: Fix APFS volume help message
  * changevm: Fix "cpus" and "mem" arguments
  * ci: Add code quality checks for PRs
  * Fix some cargo and clippy warnings
  * fix compile failures on macos m1
  * README.md: Add "Supported platforms"
  * Bump version to 0.1.3
* Fri Oct  1 2021 Dario Faggioli <dfaggioli@suse.com>
- Fix the build, after the libkrun pakaging changes and the switch to cargo
  * libkrun-devel and libkrun0 packages no longer exist, while
    libkrun does. Make sure that we depend on that one.
  * fix quoting around RUSTFLAGS so that we don't miss flags
* Thu Sep 30 2021 William Brown <william.brown@suse.com>
- Replace rust-packaging with cargo-packaging
* Tue Mar 23 2021 dfaggioli@suse.com
- Update to version 0.1.4+git5add8c5:
  * chore: add Cargo.lock file
  * Create directory leading up to resolv.conf
- Change versioning scheme (to include the git commit hash)
* Fri Mar 19 2021 Dario Faggioli <dfaggioli@suse.com>
- let's enable only the arch-es for which we have libkrun
* Fri Mar 19 2021 Dario Faggioli <dfaggioli@suse.com>
- there's no libkrun for i586 so let's exclude it here too
* Sat Feb 27 2021 Dario Faggioli <dfaggioli@suse.com>
- Set all services to disabled
* Thu Feb 18 2021 dmacvicar@suse.com
- Update to version 0.1.4:
  * Bump version to 0.1.4
  * main: Fix APFS volume help message
  * changevm: Fix "cpus" and "mem" arguments
  * ci: Add code quality checks for PRs
  * Fix some cargo and clippy warnings
  * fix compile failures on macos m1
  * README.md: Add "Supported platforms"
  * Bump version to 0.1.3
  * Don't check for "unshare" if running as root
  * Bump version to 0.1.2
* Thu Feb 18 2021 Duncan Mac-Vicar <duncan@mac-vicar.eu>
- Initial package for 1.4.1
  Based on Fedora package by Sergio Lopez <slp@redhat.com>
